import { Router } from 'express'
import jwt from 'jsonwebtoken'

import { requiredFields } from '../../utils/required'
import { adminAxios } from '../../utils/admin-axios'
import { registerUser } from './auth.controller'
import { getAnswer } from '../../utils/common'

export const authRouter = Router()

authRouter.post('/sign-in', requiredFields(['password', 'login']), (req, res, next) => {
    const { password, login } = req.body

    adminAxios({
        url: '/auth/sign-in',
        data: {
            password,
            login
        }
    })
        .then(answer => {
            registerUser(answer?.data?.user)
                .then((user) => {
                    const { id, ijlId, ijlUser: { username, role } } = user
                    const token = jwt.sign({ id, username, role, ijlId }, process.env.JWT_SECRET_STRING, {
                        expiresIn: '2 days'
                    })

                    res.send(getAnswer(null, { token, user }))
                })
        })
        .catch(error => {
            console.log(error)
            next(new Error(error))
        })

    // const { hash: _hash, salt: _salt, ...cleanUser } = user

    // req.session.user = cleanUser
    // const token = jwt.sign(cleanUser, process.env.JWT_SECRET_STRING, {
    //     expiresIn: '2 days'
    // });
    
    // return res.send({ token, user: cleanUser })

    // res.status(400).send({ error: 'Login or password does\'t match' })
})
